#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bifunctors
version:              5.6.3
visibility:           public
id:                   bifunctors-5.6.3-7bjHyYyfYBQARUyvp7mikv
key:                  bifunctors-5.6.3-7bjHyYyfYBQARUyvp7mikv
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/bifunctors/
synopsis:             Bifunctors
description:          Bifunctors.
category:             Data, Functors
abi:                  676406bb76e99be13ea9cbd7f4c5b708
exposed:              True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biap Data.Bifunctor.Biff
    Data.Bifunctor.Clown Data.Bifunctor.Fix Data.Bifunctor.Flip
    Data.Bifunctor.Functor Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Sum Data.Bifunctor.TH
    Data.Bifunctor.Tannen Data.Bifunctor.Wrapped

hidden-modules:       Data.Bifunctor.TH.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bifunctors-5.6.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bifunctors-5.6.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bifunctors-5.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bifunctors
hs-libraries:         HSbifunctors-5.6.3-7bjHyYyfYBQARUyvp7mikv
depends:
    assoc-1.1.1-Nt8kqA7BxIACry821zOJa base-4.18.2.1
    comonad-5.0.10-INQrKwVXtFu7D2yogc2Nby containers-0.6.7
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j template-haskell-2.20.0.0
    th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3

haddock-interfaces:   /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html:         /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

